@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.002';     # TRIAL VERSION
+our $VERSION = '0.003';     # TRIAL VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -45,6 +45,22 @@ with 'WebService::Avalara::AvaTax::Role::Connection';
 #pod call the AvaTax service, or the C<wsdl> method to access the underlying
 #pod L<XML::Compile::WSDL11|XML::Compile::WSDL11> object.
 #pod
+#pod =head1 SEE ALSO
+#pod
+#pod =over
+#pod
+#pod =item L<Business::Tax::Avalara|Business::Tax::Avalara>
+#pod
+#pod An alternative that uses Avalara's REST API.
+#pod
+#pod =item L<XML::Compile::SOAP|XML::Compile::SOAP> and L<XML::Compile::WSDL11|XML::Compile::WSDL11>
+#pod
+#pod Part of the L<XML::Compile|XML::Compile> suite
+#pod and the basis for this distribution. It's helpful to understand these in
+#pod order to debug or extend this module.
+#pod
+#pod =back
+#pod
 #pod =for Pod::Coverage BUILD
 #pod
 #pod =head1 METHODS
@@ -127,7 +143,7 @@ WebService::Avalara::AvaTax - Avalara SOAP interface as compiled Perl methods
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -283,6 +299,22 @@ attribute to access the L<LWP::UserAgent|LWP::UserAgent> used to retrieve and
 call the AvaTax service, or the C<wsdl> method to access the underlying
 L<XML::Compile::WSDL11|XML::Compile::WSDL11> object.
 
+=head1 SEE ALSO
+
+=over
+
+=item L<Business::Tax::Avalara|Business::Tax::Avalara>
+
+An alternative that uses Avalara's REST API.
+
+=item L<XML::Compile::SOAP|XML::Compile::SOAP> and L<XML::Compile::WSDL11|XML::Compile::WSDL11>
+
+Part of the L<XML::Compile|XML::Compile> suite
+and the basis for this distribution. It's helpful to understand these in
+order to debug or extend this module.
+
+=back
+
 =for Pod::Coverage BUILD
 
 =head1 SUPPORT
@@ -398,7 +430,9 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by ZipRecruiter.  No
-license is granted to other entities.
+This software is copyright (c) 2015 by ZipRecruiter.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
